==> zio-aws-amplifybackend_3-5.17.124.2-sources.jar: zio/aws/amplifybackend/model/CreateBackendAuthRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class CreateBackendAuthRequest(
    appId: __string,
    backendEnvironmentName: __string,
    resourceConfig: zio.aws.amplifybackend.model.CreateBackendAuthResourceConfig,
    resourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthRequest = {
    import CreateBackendAuthRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthRequest
      .builder()
      .appId(__string.unwrap(appId): java.lang.String)
      .backendEnvironmentName(
        __string.unwrap(backendEnvironmentName): java.lang.String
      )
      .resourceConfig(resourceConfig.buildAwsValue())
      .resourceName(__string.unwrap(resourceName): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.CreateBackendAuthRequest.ReadOnly =
    zio.aws.amplifybackend.model.CreateBackendAuthRequest.wrap(buildAwsValue())
}
object CreateBackendAuthRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.CreateBackendAuthRequest =
      zio.aws.amplifybackend.model.CreateBackendAuthRequest(
        appId,
        backendEnvironmentName,
        resourceConfig.asEditable,
        resourceName
      )
    def appId: __string
    def backendEnvironmentName: __string
    def resourceConfig
        : zio.aws.amplifybackend.model.CreateBackendAuthResourceConfig.ReadOnly
    def resourceName: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getBackendEnvironmentName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(backendEnvironmentName)
    def getResourceConfig: ZIO[
      Any,
      Nothing,
      zio.aws.amplifybackend.model.CreateBackendAuthResourceConfig.ReadOnly
    ] = ZIO.succeed(resourceConfig)
    def getResourceName: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthRequest
  ) extends zio.aws.amplifybackend.model.CreateBackendAuthRequest.ReadOnly {
    override val appId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.appId())
    override val backendEnvironmentName: __string =
      zio.aws.amplifybackend.model.primitives
        .__string(impl.backendEnvironmentName())
    override val resourceConfig
        : zio.aws.amplifybackend.model.CreateBackendAuthResourceConfig.ReadOnly =
      zio.aws.amplifybackend.model.CreateBackendAuthResourceConfig
        .wrap(impl.resourceConfig())
    override val resourceName: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.resourceName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthRequest
  ): zio.aws.amplifybackend.model.CreateBackendAuthRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifybackend_3-5.17.265.1-sources.jar: zio/aws/amplifybackend/model/CreateBackendAuthRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class CreateBackendAuthRequest(
    appId: __string,
    backendEnvironmentName: __string,
    resourceConfig: zio.aws.amplifybackend.model.CreateBackendAuthResourceConfig,
    resourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthRequest = {
    import CreateBackendAuthRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthRequest
      .builder()
      .appId(appId: java.lang.String)
      .backendEnvironmentName(backendEnvironmentName: java.lang.String)
      .resourceConfig(resourceConfig.buildAwsValue())
      .resourceName(resourceName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.CreateBackendAuthRequest.ReadOnly =
    zio.aws.amplifybackend.model.CreateBackendAuthRequest.wrap(buildAwsValue())
}
object CreateBackendAuthRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.CreateBackendAuthRequest =
      zio.aws.amplifybackend.model.CreateBackendAuthRequest(
        appId,
        backendEnvironmentName,
        resourceConfig.asEditable,
        resourceName
      )
    def appId: __string
    def backendEnvironmentName: __string
    def resourceConfig
        : zio.aws.amplifybackend.model.CreateBackendAuthResourceConfig.ReadOnly
    def resourceName: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getBackendEnvironmentName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(backendEnvironmentName)
    def getResourceConfig: ZIO[
      Any,
      Nothing,
      zio.aws.amplifybackend.model.CreateBackendAuthResourceConfig.ReadOnly
    ] = ZIO.succeed(resourceConfig)
    def getResourceName: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthRequest
  ) extends zio.aws.amplifybackend.model.CreateBackendAuthRequest.ReadOnly {
    override val appId: __string = impl.appId(): __string
    override val backendEnvironmentName: __string =
      impl.backendEnvironmentName(): __string
    override val resourceConfig
        : zio.aws.amplifybackend.model.CreateBackendAuthResourceConfig.ReadOnly =
      zio.aws.amplifybackend.model.CreateBackendAuthResourceConfig
        .wrap(impl.resourceConfig())
    override val resourceName: __string = impl.resourceName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateBackendAuthRequest
  ): zio.aws.amplifybackend.model.CreateBackendAuthRequest.ReadOnly =
    new Wrapper(impl)
}
